@@ -40,10 +40,12 @@
 
 #include <libgnomeui/gnome-ice.h>
 #include <libgnome/libgnome.h>
+#include <gconf/gconf-client.h>
 
 #include "ice.h"
 #include "session.h"
 #include "manager.h"
+#include "util.h"
 
 /* Network ids.  */
 static char* ids;
@@ -84,7 +86,8 @@ my_ice_error_handler(IceConn cnx,
 	int severity,
 	IcePointer values)
 {
-      IceCloseConnection(cnx);
+  gsm_verbose ("Closing connection: %p\n", cnx);
+  IceCloseConnection(cnx);
 }
 
 static void
@@ -99,9 +102,14 @@ accept_connection (GIOChannel   *source,
   char *ctmp;
 #endif
 
+  gsm_verbose ("Acception a connection...\n");
+
   connection = IceAcceptConnection (listener, &status);
   if (status != IceAcceptSuccess)
-    return;
+    {
+      gsm_verbose ("IceAcceptConnection returned %d\n", status);
+      return;
+    }
 
 #if defined(HAVE_TCPD_H) && defined(HAVE_HOSTS_ACCESS) && defined(HAVE_SYSLOG_H)
   ctmp = IceGetListenConnectionString (listener);
@@ -129,10 +137,12 @@ accept_connection (GIOChannel   *source,
       /* Freeze ice while doing the gtk iteration. We don't want to recurse
          here */
       ice_frozen();
+      gsm_verbose ("iterate...\n");
       g_main_context_iteration (NULL, TRUE);
       ice_thawed();
       status2 = IceConnectionStatus (connection);
     }
+  gsm_verbose ("Done.\n");
 }
 
 static guint
@@ -141,6 +151,8 @@ ice_add_listener (IceListenObj listener)
   GIOChannel *channel;
   guint       retval;
 
+  gsm_verbose ("Adding listener for %p\n", listener);
+
   channel = g_io_channel_unix_new (IceGetListenConnectionNumber (listener));
 
   retval = g_io_add_watch (
@@ -156,6 +168,9 @@ static void
 ice_watch (IceConn connection, IcePointer client_data, Bool opening,
 	   IcePointer *watch_data)
 {
+
+  gsm_verbose ("ice_watch():\tconnection: %p\topening: %d\n", connection, opening);
+
   if (opening)
     {
       Watch *watch = g_new0 (Watch, 1); 
@@ -178,6 +193,9 @@ ice_set_clean_up_handler (IceConn connection,
 			  GDestroyNotify clean_up, gpointer data)
 {
   GSList* list;
+
+  gsm_verbose ("setting clean up handler for connection %p\n", connection);
+
   for (list = watch_list; list; list = list->next)
     {
       Watch *watch = (Watch*)list->data;
@@ -214,7 +232,8 @@ startup_clean_ice (void)
 	  IceAuthFileEntry *file_entry = (IceAuthFileEntry *)list->data;
 
 	  list = list->next;
-	  if (!strcmp (file_entry->network_id, network_id))
+	  /* remove "bad" entries with no network_id */
+	  if (!file_entry->network_id || !strcmp (file_entry->network_id, network_id))
 	    {
 	      REMOVE (entries, file_entry);
 	      IceFreeAuthFileEntry (file_entry);
@@ -288,8 +307,7 @@ initialize_ice (void)
   saved_umask = umask (0);
   umask (saved_umask);
 
-  allow_tcp = gnome_config_get_bool ("/" GSM_OPTION_CONFIG_PREFIX
-				     ALLOW_TCP_KEY"="ALLOW_TCP_DEFAULT);
+  allow_tcp = gconf_client_get_bool (gconf_client_get_default (), ALLOW_TCP_KEY, NULL);
  
   if (SmsInitialize (GsmVendor, VERSION, new_client, NULL,
 		     auth_proc, sizeof error, error)) 
@@ -335,7 +353,8 @@ initialize_ice (void)
 	  IceAuthFileEntry *file_entry = (IceAuthFileEntry *)list->data;
 
 	  list = list->next;
-	  if (!strcmp (file_entry->network_id, network_id))
+	  /* remove "bad" entries with no network_id */
+	  if (!file_entry->network_id || !strcmp (file_entry->network_id, network_id))
 	    {
 	      REMOVE (entries, file_entry);
 	      IceFreeAuthFileEntry (file_entry);
@@ -388,7 +407,10 @@ void ice_frozen (void)
 	if (++ice_depth == 1)
 		/* First disable so turn off the events */
 		for (i = 0; i < num_sockets; i++)
-			g_source_remove (input_id [i]);      
+		  {
+		    gsm_verbose ("Removing listener for %p\n", sockets[i]);
+		    g_source_remove (input_id [i]);
+		  }
 }
 
 void
@@ -409,14 +431,16 @@ clean_ice (void)
 	  IceAuthFileEntry *file_entry = (IceAuthFileEntry *)list->data;
 
 	  list = list->next;
-	  if (!strcmp (file_entry->network_id, network_id))
+	  /* remove "bad" entries with no network_id */
+	  if (!file_entry->network_id || !strcmp (file_entry->network_id, network_id))
 	    {
 	      REMOVE (entries, file_entry);
 	      IceFreeAuthFileEntry (file_entry);
 	    }
 	}
 
-      g_source_remove (input_id [i]);      
+      gsm_verbose ("Removing listener for %p\n", sockets[i]);
+      g_source_remove (input_id [i]);
       free (network_id);
     }
 
